@@ -3,7 +3,7 @@
                              "DecreasingConcave", "IncreasingConcave", "DecreasingConvex",
                              "IncreasingS", "DecreasingS", "IncreasingRotatedS",
                              "DecreasingRotatedS", "InvertedU", "Ushape"),
-                   marginal.likelihood = TRUE, spm.adequacy = FALSE) {
+                   marginal.likelihood = TRUE, spm.adequacy = FALSE, verbose = FALSE) {
   cl <- match.call()
 
   ywxdata <- interpret.bsam(formula)
@@ -89,7 +89,7 @@
     maxmodmet <- 0
 
   mcmctime <- system.time({
-    foo <- .Fortran("bsaram", as.double(yobs), as.matrix(wdata), as.matrix(xobs), as.integer(nobs), as.integer(nparw),
+    foo <- .Fortran("bsaram", as.integer(verbose), as.double(yobs), as.matrix(wdata), as.matrix(xobs), as.integer(nobs), as.integer(nparw),
                     as.integer(nfun), as.integer(nbasis), as.integer(nint), as.integer(fmodel), as.double(fpm), as.double(theta0_m0),
                     as.double(theta0_s0), as.double(tau2_m0), as.double(tau2_v0), as.double(w0), as.double(beta_m0), as.matrix(beta_v0),
                     as.double(alpha_m0), as.double(alpha_s0), as.double(psi_m0), as.double(psi_s0), as.double(psifixed), as.double(omega_m0),
