@@ -1,4 +1,4 @@
-subroutine bsaramdpscale(yobs,wdata,xobs,nobs,nparw,nfun,nbasis,nint,fmodel,fpm,&
+subroutine bsaramdpscale(verbose,yobs,wdata,xobs,nobs,nparw,nfun,nbasis,nint,fmodel,fpm,&
                          theta0_m0,theta0_s0,tau2_m0,tau2_v0,w0,beta_m0,beta_v0,&
                          alpha_m0,alpha_s0,psi_m0,psi_s0,psifixed,omega_m0,omega_s0,&
                          sigma2_r0,sigma2_s0,tmass_a,tmass_b,&
@@ -14,7 +14,7 @@ implicit none
 !input arguments
 integer,intent(in) :: nobs,nparw,nfun,nbasis,nint,fmodel(nfun)
 integer,intent(in) :: maxmodmet,nblow0,nblow,smcmc,nskip,ndisp
-integer,intent(in) :: ngrid,iflagprior,iflagpsi
+integer,intent(in) :: ngrid,iflagprior,iflagpsi,verbose
 real(8), intent(in) :: yobs(nobs),wdata(nobs,nparw),xobs(nobs,nfun),fpm(nfun)
 real(8), intent(in) :: theta0_m0,theta0_s0,egrid(ngrid)
 real(8), intent(in) :: tau2_m0,tau2_v0,w0,beta_m0(nparw),beta_v0(nparw,nparw)
@@ -491,19 +491,23 @@ isave=1
 nmcmc=nblow+nskip*smcmc
 do imcmc=1,nmcmc
   if(imcmc.eq.1) then
-    call dblepr('Burnin ...',-1,1.d0,0)
+    if (verbose.eq.1) then
+      call dblepr('Burnin ...',-1,1.d0,0)
+    end if
     pmet=0
   end if
   call rchkusr()
   call GetMCMC()
 
   if(imcmc.eq.nblow) then
-    do ifun=1,nfun
-      if(fmodel(ifun).gt.1) then
-        call aprint(ifun, dble(pmet(ifun))/dble(nblow))
-      end if
-    end do
-    call dblepr('Main iterations ...',-1,1.d0,0)
+    if (verbose.eq.1) then
+      do ifun=1,nfun
+        if(fmodel(ifun).gt.1) then
+          call aprint(ifun, dble(pmet(ifun))/dble(nblow))
+        end if
+      end do
+      call dblepr('Main iterations ...',-1,1.d0,0)
+    end if
     pmet=0
   end if
 
@@ -531,20 +535,24 @@ do imcmc=1,nmcmc
 
     edensg(isave,:)=edens
 
-    if (mod(isave,ndisp).eq.0) then
-      call cpu_time(itime)
-      call sprint(isave,smcmc,itime-stime)
+    if (verbose.eq.1) then
+      if (mod(isave,ndisp).eq.0) then
+        call cpu_time(itime)
+        call sprint(isave,smcmc,itime-stime)
+      end if
     end if
     isave=isave+1
   end if
 end do
 deallocate(phixobsfree,phixobsfreet,phixobs,phixgridfree,phixgrid)
 pmetg=dble(pmet)/dble(smcmc*nskip)
-do ifun=1,nfun
-  if(fmodel(ifun).gt.1) then
-    call aprint(ifun, pmetg(ifun))
-  end if
-end do
+if (verbose.eq.1) then
+  do ifun=1,nfun
+    if(fmodel(ifun).gt.1) then
+      call aprint(ifun, pmetg(ifun))
+    end if
+  end do
+end if
 call rndend()
 
 !=========================================================================================
